summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--macosx/tkMacOSXColor.c6
-rw-r--r--macosx/tkMacOSXDraw.c6
-rw-r--r--macosx/tkMacOSXEmbed.c2
-rw-r--r--macosx/tkMacOSXEntry.c4
-rw-r--r--macosx/tkMacOSXFont.c2
-rw-r--r--macosx/tkMacOSXImage.c12
-rw-r--r--macosx/tkMacOSXKeyEvent.c2
-rw-r--r--macosx/tkMacOSXMenu.c2
-rw-r--r--macosx/tkMacOSXMouseEvent.c4
-rw-r--r--macosx/tkMacOSXPrivate.h2
-rw-r--r--macosx/tkMacOSXScale.c2
-rw-r--r--macosx/tkMacOSXScrlbr.c12
-rw-r--r--macosx/tkMacOSXSubwindows.c38
-rw-r--r--macosx/tkMacOSXTest.c2
-rw-r--r--macosx/tkMacOSXWindowEvent.c2
-rw-r--r--macosx/tkMacOSXWm.c18
-rw-r--r--macosx/tkMacOSXXStubs.c4
-rw-r--r--macosx/ttkMacOSXTheme.c4
18 files changed, 62 insertions, 62 deletions
diff --git a/macosx/tkMacOSXColor.c b/macosx/tkMacOSXColor.c
index fd39197..8885792 100644
--- a/macosx/tkMacOSXColor.c
+++ b/macosx/tkMacOSXColor.c
@@ -438,7 +438,7 @@ TkMacOSXInDarkMode(Tk_Window tkwin)
NSAppearanceName name;
NSView *view = nil;
if (winPtr && winPtr->privatePtr) {
- view = TkMacOSXDrawableView((Drawable)winPtr->privatePtr);
+ view = TkMacOSXGetNSViewForDrawable((Drawable)winPtr->privatePtr);
}
if (view) {
name = [[view effectiveAppearance] name];
@@ -747,8 +747,8 @@ TkpGetColor(
}
if (tkwin) {
display = Tk_Display(tkwin);
- Drawable d = (Drawable)Tk_WindowId(tkwin);
- view = TkMacOSXDrawableView(d);
+ Drawable d = Tk_WindowId(tkwin);
+ view = TkMacOSXGetNSViewForDrawable(d);
}
/*
diff --git a/macosx/tkMacOSXDraw.c b/macosx/tkMacOSXDraw.c
index 1c77af3..06d1810 100644
--- a/macosx/tkMacOSXDraw.c
+++ b/macosx/tkMacOSXDraw.c
@@ -1140,7 +1140,7 @@ TkScrollWindow(
{
Drawable drawable = Tk_WindowId(tkwin);
MacDrawable *macDraw = (MacDrawable *)drawable;
- TKContentView *view = TkMacOSXDrawableView(macDraw);
+ TKContentView *view = (TKContentView *)TkMacOSXGetNSViewForDrawable(macDraw);
CGRect srcRect, dstRect;
HIShapeRef dmgRgn = NULL, extraRgn = NULL;
NSRect bounds, visRect, scrollSrc, scrollDst;
@@ -1271,7 +1271,7 @@ TkMacOSXSetupDrawingContext(
*/
if (!(macDraw->flags & TK_IS_PIXMAP)) {
- view = TkMacOSXDrawableView(d);
+ view = (TKContentView *)TkMacOSXGetNSViewForDrawable(d);
if (!view) {
Tcl_Panic("TkMacOSXSetupDrawingContext(): "
"no NSView to draw into !");
@@ -1523,7 +1523,7 @@ TkMacOSXGetClipRgn(
#ifdef TK_MAC_DEBUG_DRAWING
TkMacOSXDbgMsg("%s", macDraw->winPtr->pathName);
- NSView *view = TkMacOSXDrawableView(macDraw);
+ NSView *view = TkMacOSXGetNSViewForDrawable(macDraw);
CGContextRef context = GET_CGCONTEXT;
CGContextSaveGState(context);
diff --git a/macosx/tkMacOSXEmbed.c b/macosx/tkMacOSXEmbed.c
index acf2e69..dc43726 100644
--- a/macosx/tkMacOSXEmbed.c
+++ b/macosx/tkMacOSXEmbed.c
@@ -446,7 +446,7 @@ TkMacOSXContainerId(
for (containerPtr = firstContainerPtr; containerPtr != NULL;
containerPtr = containerPtr->nextPtr) {
if (containerPtr->embeddedPtr == winPtr) {
- return (MacDrawable *) containerPtr->parent;
+ return (MacDrawable *)containerPtr->parent;
}
}
Tcl_Panic("TkMacOSXContainerId couldn't find window");
diff --git a/macosx/tkMacOSXEntry.c b/macosx/tkMacOSXEntry.c
index c6f4eea..75cd198 100644
--- a/macosx/tkMacOSXEntry.c
+++ b/macosx/tkMacOSXEntry.c
@@ -92,7 +92,7 @@ TkpDrawEntryBorderAndFocus(
GC bgGC;
Tk_Window tkwin = entryPtr->tkwin;
int oldWidth = 0;
- MacDrawable *macDraw = (MacDrawable *) d;
+ MacDrawable *macDraw = (MacDrawable *)d;
const HIThemeFrameDrawInfo info = {
.version = 0,
.kind = kHIThemeFrameTextFieldSquare,
@@ -208,7 +208,7 @@ TkpDrawSpinboxButtons(
TkMacOSXDrawingContext dc;
XRectangle rects[1];
GC bgGC;
- MacDrawable *macDraw = (MacDrawable *) d;
+ MacDrawable *macDraw = (MacDrawable *)d;
HIThemeButtonDrawInfo info = {
.version = 0,
.adornment = kThemeAdornmentNone,
diff --git a/macosx/tkMacOSXFont.c b/macosx/tkMacOSXFont.c
index 4e383f1..f7b87dc 100644
--- a/macosx/tkMacOSXFont.c
+++ b/macosx/tkMacOSXFont.c
@@ -1189,7 +1189,7 @@ TkpDrawAngledCharsInContext(
CTTypesetterRef typesetter;
CFIndex start, length;
CTLineRef line, full=nil;
- MacDrawable *macWin = (MacDrawable *) drawable;
+ MacDrawable *macWin = (MacDrawable *)drawable;
TkMacOSXDrawingContext drawingContext;
CGContextRef context;
CGColorRef fg;
diff --git a/macosx/tkMacOSXImage.c b/macosx/tkMacOSXImage.c
index 38e14fa..2604dfa 100644
--- a/macosx/tkMacOSXImage.c
+++ b/macosx/tkMacOSXImage.c
@@ -417,7 +417,7 @@ XPutImage(
unsigned int height) /* distination and source. */
{
TkMacOSXDrawingContext dc;
- MacDrawable *macDraw = (MacDrawable *) drawable;
+ MacDrawable *macDraw = (MacDrawable *)drawable;
display->request++;
if (!TkMacOSXSetupDrawingContext(drawable, gc, &dc)) {
@@ -526,7 +526,7 @@ CreateCGImageFromDrawableRect(
unsigned int width,
unsigned int height)
{
- MacDrawable *mac_drawable = (MacDrawable *) drawable;
+ MacDrawable *mac_drawable = (MacDrawable *)drawable;
CGContextRef cg_context = NULL;
CGImageRef cg_image = NULL, result = NULL;
NSBitmapImageRep *bitmapRep = NULL;
@@ -544,7 +544,7 @@ CreateCGImageFromDrawableRect(
result = CGImageCreateWithImageInRect(cg_image, image_rect);
CGImageRelease(cg_image);
}
- } else if (TkMacOSXDrawableView(mac_drawable) != NULL) {
+ } else if (TkMacOSXGetNSViewForDrawable(mac_drawable) != NULL) {
/*
* Convert Tk top-left to NSView bottom-left coordinates.
@@ -746,7 +746,7 @@ XCopyArea(
int dest_y)
{
TkMacOSXDrawingContext dc;
- MacDrawable *srcDraw = (MacDrawable *) src;
+ MacDrawable *srcDraw = (MacDrawable *)src;
CGImageRef img = NULL;
CGRect bounds, srcRect, dstRect;
@@ -821,8 +821,8 @@ XCopyPlane(
unsigned long plane) /* Which plane to copy. */
{
TkMacOSXDrawingContext dc;
- MacDrawable *srcDraw = (MacDrawable *) src;
- MacDrawable *dstDraw = (MacDrawable *) dst;
+ MacDrawable *srcDraw = (MacDrawable *)src;
+ MacDrawable *dstDraw = (MacDrawable *)dst;
CGRect bounds, srcRect, dstRect;
display->request++;
if (!width || !height) {
diff --git a/macosx/tkMacOSXKeyEvent.c b/macosx/tkMacOSXKeyEvent.c
index 49d38a6..fdf4e66 100644
--- a/macosx/tkMacOSXKeyEvent.c
+++ b/macosx/tkMacOSXKeyEvent.c
@@ -688,7 +688,7 @@ XGrabKeyboard(
if (keyboardGrabWinPtr && captureWinPtr) {
NSWindow *w = TkMacOSXGetNSWindowForDrawable(grab_window);
- MacDrawable *macWin = (MacDrawable *) grab_window;
+ MacDrawable *macWin = (MacDrawable *)grab_window;
if (w && macWin->toplevel->winPtr == (TkWindow *) captureWinPtr) {
if (modalSession) {
diff --git a/macosx/tkMacOSXMenu.c b/macosx/tkMacOSXMenu.c
index 321b4f8..9ba7ce8 100644
--- a/macosx/tkMacOSXMenu.c
+++ b/macosx/tkMacOSXMenu.c
@@ -881,7 +881,7 @@ TkpPostMenu(
* rather than the appearance of the root window.
*/
realWinPtr = (TkWindow*) realWin;
- realWinView = TkMacOSXDrawableView(realWinPtr->privatePtr);
+ realWinView = TkMacOSXGetNSViewForDrawable(realWinPtr->privatePtr);
if (realWinView != nil) {
break;
}
diff --git a/macosx/tkMacOSXMouseEvent.c b/macosx/tkMacOSXMouseEvent.c
index f2d7e32..805b028 100644
--- a/macosx/tkMacOSXMouseEvent.c
+++ b/macosx/tkMacOSXMouseEvent.c
@@ -431,7 +431,7 @@ XQueryPointer(
NSPoint global = [NSEvent mouseLocation];
if (getLocal) {
- MacDrawable *macWin = (MacDrawable *) w;
+ MacDrawable *macWin = (MacDrawable *)w;
NSWindow *win = TkMacOSXGetNSWindowForDrawable(w);
if (win) {
@@ -521,7 +521,7 @@ TkGenerateButtonEvent(
Window window, /* X Window containing button event. */
unsigned int state) /* Button Key state suitable for X event. */
{
- MacDrawable *macWin = (MacDrawable *) window;
+ MacDrawable *macWin = (MacDrawable *)window;
NSWindow *win = TkMacOSXGetNSWindowForDrawable(window);
MouseEventData med;
diff --git a/macosx/tkMacOSXPrivate.h b/macosx/tkMacOSXPrivate.h
index 5ac834c..1347035 100644
--- a/macosx/tkMacOSXPrivate.h
+++ b/macosx/tkMacOSXPrivate.h
@@ -258,7 +258,7 @@ MODULE_SCOPE void TkMacOSXRestoreDrawingContext(
MODULE_SCOPE void TkMacOSXSetColorInContext(GC gc, unsigned long pixel,
CGContextRef context);
#define TkMacOSXGetNSWindowForDrawable(drawable) ((NSWindow*)TkMacOSXDrawable(drawable))
-#define TkMacOSXDrawableView(macWin) (TKContentView *)TkMacOSXGetRootControl((Drawable)(macWin))
+#define TkMacOSXGetNSViewForDrawable(macWin) (NSView *)TkMacOSXGetRootControl((Drawable)(macWin))
MODULE_SCOPE void TkMacOSXWinCGBounds(TkWindow *winPtr, CGRect *bounds);
MODULE_SCOPE HIShapeRef TkMacOSXGetClipRgn(Drawable drawable);
MODULE_SCOPE void TkMacOSXInvalidateViewRegion(NSView *view,
diff --git a/macosx/tkMacOSXScale.c b/macosx/tkMacOSXScale.c
index 15286d6..5da13d4 100644
--- a/macosx/tkMacOSXScale.c
+++ b/macosx/tkMacOSXScale.c
@@ -213,7 +213,7 @@ TkpDisplayScale(
* Set up port for drawing Macintosh control.
*/
- macDraw = (MacDrawable *) Tk_WindowId(tkwin);
+ macDraw = (MacDrawable *)Tk_WindowId(tkwin);
windowRef = TkMacOSXGetNSWindowForDrawable(Tk_WindowId(tkwin));
/*
diff --git a/macosx/tkMacOSXScrlbr.c b/macosx/tkMacOSXScrlbr.c
index e70867d..2d9a038 100644
--- a/macosx/tkMacOSXScrlbr.c
+++ b/macosx/tkMacOSXScrlbr.c
@@ -174,8 +174,8 @@ static void drawMacScrollbar(
MacScrollbar *msPtr,
CGContextRef context)
{
- Drawable d = (Drawable)Tk_WindowId(scrollPtr->tkwin);
- NSView *view = TkMacOSXDrawableView(d);
+ Drawable d = Tk_WindowId(scrollPtr->tkwin);
+ NSView *view = TkMacOSXGetNSViewForDrawable(d);
CGPathRef path;
CGPoint inner[2], outer[2], thumbOrigin;
CGSize thumbSize;
@@ -258,8 +258,8 @@ TkpDisplayScrollbar(
return;
}
- MacDrawable *macWin = (MacDrawable *) winPtr->window;
- NSView *view = TkMacOSXDrawableView(macWin);
+ MacDrawable *macWin = (MacDrawable *)winPtr->window;
+ NSView *view = TkMacOSXGetNSViewForDrawable(macWin);
if ((view == NULL)
|| (macWin->flags & TK_DO_NOT_DRAW)
@@ -589,12 +589,12 @@ UpdateControlValues(
{
MacScrollbar *msPtr = (MacScrollbar *) scrollPtr;
Tk_Window tkwin = scrollPtr->tkwin;
- MacDrawable *macWin = (MacDrawable *) Tk_WindowId(scrollPtr->tkwin);
+ MacDrawable *macWin = (MacDrawable *)Tk_WindowId(scrollPtr->tkwin);
double dViewSize;
HIRect contrlRect;
short width, height;
- NSView *view = TkMacOSXDrawableView(macWin);
+ NSView *view = TkMacOSXGetNSViewForDrawable(macWin);
CGFloat viewHeight = [view bounds].size.height;
NSRect frame;
diff --git a/macosx/tkMacOSXTest.c b/macosx/tkMacOSXTest.c
index 434504f..8e4a030 100644
--- a/macosx/tkMacOSXTest.c
+++ b/macosx/tkMacOSXTest.c
@@ -152,7 +152,7 @@ MODULE_SCOPE Bool
TkTestLogDisplay(
Drawable drawable)
{
- MacDrawable *macWin = (MacDrawable *) drawable;
+ MacDrawable *macWin = (MacDrawable *)drawable;
NSWindow *win = nil;
if (macWin->toplevel && macWin->toplevel->winPtr &&
macWin->toplevel->winPtr->wmInfoPtr &&
diff --git a/macosx/tkMacOSXWindowEvent.c b/macosx/tkMacOSXWindowEvent.c
index 8b1e694..3d9120f 100644
--- a/macosx/tkMacOSXWindowEvent.c
+++ b/macosx/tkMacOSXWindowEvent.c
@@ -427,7 +427,7 @@ TkpWillDrawWidget(Tk_Window tkwin) {
int result;
if (tkwin) {
TkWindow *winPtr = (TkWindow *)tkwin;
- TKContentView *view = TkMacOSXDrawableView(
+ TKContentView *view = (TKContentView *)TkMacOSXGetNSViewForDrawable(
(Drawable)winPtr->privatePtr);
result = ([NSApp isDrawing] && view == [NSView focusView]);
#if 0
diff --git a/macosx/tkMacOSXWm.c b/macosx/tkMacOSXWm.c
index 453f277..d97ef64 100644
--- a/macosx/tkMacOSXWm.c
+++ b/macosx/tkMacOSXWm.c
@@ -969,7 +969,7 @@ TkWmDeadWindow(
NSWindow *parent = [ourNSWindow parentWindow];
TkMacOSXUnregisterMacWindow(ourNSWindow);
if (winPtr->window) {
- ((MacDrawable *) winPtr->window)->view = nil;
+ ((MacDrawable *)winPtr->window)->view = nil;
}
wmPtr->window = NULL;
@@ -1433,7 +1433,7 @@ WmSetAttribute(
oldFlags, 1, 0);
[macWindow setBackgroundColor:boolean ? [NSColor clearColor] : nil];
[macWindow setOpaque:!boolean];
- TkMacOSXInvalidateWindow((MacDrawable *) winPtr->window,
+ TkMacOSXInvalidateWindow((MacDrawable *)winPtr->window,
TK_PARENT_WINDOW);
}
break;
@@ -1939,7 +1939,7 @@ WmForgetCmd(
Tk_MakeWindowExist(frameWin);
Tk_MakeWindowExist((Tk_Window)winPtr->parentPtr);
- macWin = (MacDrawable *) winPtr->window;
+ macWin = (MacDrawable *)winPtr->window;
TkFocusJoin(winPtr);
Tk_UnmapWindow(frameWin);
@@ -1950,7 +1950,7 @@ WmForgetCmd(
macWin->flags &= ~TK_HOST_EXISTS;
TkWmDeadWindow(winPtr);
- RemapWindows(winPtr, (MacDrawable *) winPtr->parentPtr->window);
+ RemapWindows(winPtr, (MacDrawable *)winPtr->parentPtr->window);
/*
* Make sure wm no longer manages this window
@@ -2785,7 +2785,7 @@ WmManageCmd(
WmInfo *wmPtr = winPtr->wmInfoPtr;
if (!Tk_IsTopLevel(frameWin)) {
- MacDrawable *macWin = (MacDrawable *) winPtr->window;
+ MacDrawable *macWin = (MacDrawable *)winPtr->window;
if (!Tk_IsManageable(frameWin)) {
Tcl_SetObjResult(interp, Tcl_ObjPrintf(
@@ -2801,7 +2801,7 @@ WmManageCmd(
TkWmNewWindow(winPtr);
if (winPtr->window == None) {
Tk_MakeWindowExist((Tk_Window)winPtr);
- macWin = (MacDrawable *) winPtr->window;
+ macWin = (MacDrawable *)winPtr->window;
}
}
wmPtr = winPtr->wmInfoPtr;
@@ -6048,7 +6048,7 @@ TkMacOSXMakeRealWindowExist(
return;
}
- macWin = (MacDrawable *) winPtr->window;
+ macWin = (MacDrawable *)winPtr->window;
/*
* If this is embedded, make sure its container's toplevel exists, then
@@ -7231,7 +7231,7 @@ RemapWindows(
*/
if (winPtr->window != None) {
- MacDrawable *macWin = (MacDrawable *) winPtr->window;
+ MacDrawable *macWin = (MacDrawable *)winPtr->window;
macWin->toplevel->referenceCount--;
macWin->toplevel = parentWin->toplevel;
@@ -7248,7 +7248,7 @@ RemapWindows(
for (childPtr = winPtr->childList; childPtr != NULL;
childPtr = childPtr->nextPtr) {
- RemapWindows(childPtr, (MacDrawable *) winPtr->window);
+ RemapWindows(childPtr, (MacDrawable *)winPtr->window);
}
}
diff --git a/macosx/tkMacOSXXStubs.c b/macosx/tkMacOSXXStubs.c
index ccb3991..aa1108e 100644
--- a/macosx/tkMacOSXXStubs.c
+++ b/macosx/tkMacOSXXStubs.c
@@ -466,7 +466,7 @@ XGetGeometry(
unsigned int *border_width_return,
unsigned int *depth_return)
{
- TkWindow *winPtr = ((MacDrawable *) d)->winPtr;
+ TkWindow *winPtr = ((MacDrawable *)d)->winPtr;
display->request++;
*root_return = ROOT_ID;
@@ -478,7 +478,7 @@ XGetGeometry(
*border_width_return = winPtr->changes.border_width;
*depth_return = Tk_Depth(winPtr);
} else {
- CGSize size = ((MacDrawable *) d)->size;
+ CGSize size = ((MacDrawable *)d)->size;
*x_return = 0;
*y_return = 0;
*width_return = size.width;
diff --git a/macosx/ttkMacOSXTheme.c b/macosx/ttkMacOSXTheme.c
index 95c72c4..26a25b4 100644
--- a/macosx/ttkMacOSXTheme.c
+++ b/macosx/ttkMacOSXTheme.c
@@ -153,7 +153,7 @@ static inline CGRect BoxToRect(
Drawable d,
Ttk_Box b)
{
- MacDrawable *md = (MacDrawable *) d;
+ MacDrawable *md = (MacDrawable *)d;
CGRect rect;
rect.origin.y = b.y + md->yOff;
@@ -2448,7 +2448,7 @@ static void ThumbElementDraw(
END_DRAWING
} else {
double thumbSize, trackSize, visibleSize, factor, fraction;
- MacDrawable *macWin = (MacDrawable *) Tk_WindowId(tkwin);
+ MacDrawable *macWin = (MacDrawable *)Tk_WindowId(tkwin);
CGRect troughBounds = {{macWin->xOff, macWin->yOff},
{Tk_Width(tkwin), Tk_Height(tkwin)}};
diff --git a/macosx/tkMacOSXSubwindows.c b/macosx/tkMacOSXSubwindows.c
index 24cd974..002eae6 100644
--- a/macosx/tkMacOSXSubwindows.c
+++ b/macosx/tkMacOSXSubwindows.c
@@ -54,7 +54,7 @@ XDestroyWindow(
TCL_UNUSED(Display *), /* Display. */
Window window) /* Window. */
{
- MacDrawable *macWin = (MacDrawable *) window;
+ MacDrawable *macWin = (MacDrawable *)window;
/*
* Remove any dangling pointers that may exist if the window we are
@@ -139,7 +139,7 @@ XMapWindow(
if (!window) {
return BadWindow;
}
- MacDrawable *macWin = (MacDrawable *) window;
+ MacDrawable *macWin = (MacDrawable *)window;
TkWindow *winPtr = macWin->winPtr;
NSWindow *win = TkMacOSXGetNSWindowForDrawable(window);
XEvent event;
@@ -297,7 +297,7 @@ XUnmapWindow(
Display *display, /* Display. */
Window window) /* Window. */
{
- MacDrawable *macWin = (MacDrawable *) window;
+ MacDrawable *macWin = (MacDrawable *)window;
TkWindow *winPtr = macWin->winPtr;
TkWindow *parentPtr = winPtr->parentPtr;
NSWindow *win = TkMacOSXGetNSWindowForDrawable(window);
@@ -341,7 +341,7 @@ XUnmapWindow(
if (parentPtr && parentPtr->privatePtr->visRgn) {
TkMacOSXInvalidateViewRegion(
- TkMacOSXDrawableView(parentPtr->privatePtr),
+ TkMacOSXGetNSViewForDrawable(parentPtr->privatePtr),
parentPtr->privatePtr->visRgn);
}
TkMacOSXInvalClipRgns((Tk_Window)parentPtr);
@@ -379,7 +379,7 @@ XResizeWindow(
unsigned int width,
unsigned int height)
{
- MacDrawable *macWin = (MacDrawable *) window;
+ MacDrawable *macWin = (MacDrawable *)window;
display->request++;
if (Tk_IsTopLevel(macWin->winPtr) && !Tk_IsEmbedded(macWin->winPtr)) {
@@ -424,7 +424,7 @@ XMoveResizeWindow(
unsigned int width,
unsigned int height)
{
- MacDrawable *macWin = (MacDrawable *) window;
+ MacDrawable *macWin = (MacDrawable *)window;
display->request++;
if (Tk_IsTopLevel(macWin->winPtr) && !Tk_IsEmbedded(macWin->winPtr)) {
@@ -477,7 +477,7 @@ XMoveWindow(
Window window, /* Window. */
int x, int y)
{
- MacDrawable *macWin = (MacDrawable *) window;
+ MacDrawable *macWin = (MacDrawable *)window;
display->request++;
if (Tk_IsTopLevel(macWin->winPtr) && !Tk_IsEmbedded(macWin->winPtr)) {
@@ -620,7 +620,7 @@ XRaiseWindow(
Display *display, /* Display. */
Window window) /* Window. */
{
- MacDrawable *macWin = (MacDrawable *) window;
+ MacDrawable *macWin = (MacDrawable *)window;
display->request++;
if (Tk_IsTopLevel(macWin->winPtr) && !Tk_IsEmbedded(macWin->winPtr)) {
@@ -654,7 +654,7 @@ XLowerWindow(
Display *display, /* Display. */
Window window) /* Window. */
{
- MacDrawable *macWin = (MacDrawable *) window;
+ MacDrawable *macWin = (MacDrawable *)window;
display->request++;
if (Tk_IsTopLevel(macWin->winPtr) && !Tk_IsEmbedded(macWin->winPtr)) {
@@ -692,7 +692,7 @@ XConfigureWindow(
unsigned int value_mask,
TCL_UNUSED(XWindowChanges *))
{
- MacDrawable *macWin = (MacDrawable *) w;
+ MacDrawable *macWin = (MacDrawable *)w;
TkWindow *winPtr = macWin->winPtr;
display->request++;
@@ -714,7 +714,7 @@ XConfigureWindow(
*/
if (value_mask & CWStackMode) {
- NSView *view = TkMacOSXDrawableView(macWin);
+ NSView *view = TkMacOSXGetNSViewForDrawable(macWin);
if (view) {
TkMacOSXInvalClipRgns((Tk_Window)winPtr->parentPtr);
@@ -1062,7 +1062,7 @@ TkMacOSXInvalidateWindow(
if (macWin->flags & TK_CLIP_INVALID) {
TkMacOSXUpdateClipRgn(macWin->winPtr);
}
- TkMacOSXInvalidateViewRegion(TkMacOSXDrawableView(macWin),
+ TkMacOSXInvalidateViewRegion(TkMacOSXGetNSViewForDrawable(macWin),
(flag == TK_WINDOW_ONLY) ? macWin->visRgn : macWin->aboveVisRgn);
}
@@ -1086,7 +1086,7 @@ void *
TkMacOSXDrawable(
Drawable drawable)
{
- MacDrawable *macWin = (MacDrawable *) drawable;
+ MacDrawable *macWin = (MacDrawable *)drawable;
NSWindow *result = nil;
if (!macWin || macWin->flags & TK_IS_PIXMAP) {
@@ -1135,15 +1135,15 @@ TkMacOSXGetDrawablePort(
/*
*----------------------------------------------------------------------
*
- * TkMacOSXDrawableView/TkMacOSXGetRootControl --
+ * TkMacOSXGetNSViewForDrawable/TkMacOSXGetRootControl --
*
* The function name TkMacOSXGetRootControl is being preserved only
* because it exists in a stubs table. Nobody knows what it means to
* get a "RootControl". The macro TkMacOSXDrawableView calls this
* function and should always be used rather than directly using the
* obscure official name of this function.
*
- * It returns the TKContentView for a given X drawable in the case that the
+ * It returns the NSView for a given X drawable in the case that the
* drawable is a window. If the drawable is a pixmap it returns nil.
*
* Results:
@@ -1484,7 +1484,7 @@ Tk_FreePixmap(
Display *display, /* Display. */
Pixmap pixmap) /* Pixmap to destroy */
{
- MacDrawable *macPix = (MacDrawable *) pixmap;
+ MacDrawable *macPix = (MacDrawable *)pixmap;
display->request++;
if (macPix->context) {
@@ -1135,15 +1135,15 @@ TkMacOSXGetDrawablePort(
* The function name TkMacOSXGetRootControl is being preserved only
* because it exists in a stubs table. Nobody knows what it means to
- * get a "RootControl". The macro TkMacOSXDrawableView calls this
- * function and should always be used rather than directly using the
- * obscure official name of this function.
+ * get a "RootControl". The macro TkMacOSXGetNSViewForDrawable calls
+ * this function and should always be used rather than directly using
+ * the obscure official name of this function.
*